@@ -7,6 +7,8 @@
 use std::net::SocketAddr;
 use std::path::PathBuf;
 
+use super::config::ConfigNotifyReminderBackoffFunction;
+
 pub fn server_log_level() -> String {
     "error".to_string()
 }
@@ -15,7 +17,7 @@ pub fn server_inet() -> SocketAddr {
     "[::1]:8080".parse().unwrap()
 }
 
-pub fn server_workers() -> u16 {
+pub fn server_workers() -> usize {
     4
 }
 
@@ -75,6 +77,14 @@ pub fn notify_startup_notification() -> bool {
     true
 }
 
+pub fn notify_reminder_backoff_function() -> ConfigNotifyReminderBackoffFunction {
+    ConfigNotifyReminderBackoffFunction::None
+}
+
+pub fn notify_reminder_backoff_limit() -> u16 {
+    3
+}
+
 pub fn notify_email_smtp_host() -> String {
     "localhost".to_string()
 }
