@@ -5,7 +5,6 @@
 // Copyright: 2020, Rachel Chen <rachel@chens.email>
 // License: Mozilla Public License v2.0 (MPL v2.0)
 
-use log::debug;
 use std::collections::HashMap;
 use std::time::Duration;
 
@@ -15,7 +14,7 @@ use super::generic::{GenericNotifier, Notification, DISPATCH_TIMEOUT_SECONDS};
 use crate::config::config::ConfigNotify;
 use crate::APP_CONF;
 
-lazy_static::lazy_static! {
+lazy_static! {
     static ref GOTIFY_HTTP_CLIENT: Client = Client::builder()
         .timeout(Duration::from_secs(DISPATCH_TIMEOUT_SECONDS))
         .gzip(true)
