@@ -7,7 +7,6 @@
 use std::time::{Duration, SystemTime};
 
 use indexmap::IndexMap;
-use serde_derive::Serialize;
 
 use super::mode::Mode;
 use super::replica::ReplicaURL;
@@ -19,6 +18,7 @@ pub struct ServiceStates {
     pub status: Status,
     pub date: Option<String>,
     pub probes: IndexMap<String, ServiceStatesProbe>,
+    pub notifier: ServiceStatesNotifier,
 }
 
 #[derive(Serialize)]
@@ -98,3 +98,8 @@ pub struct ServiceStatesProbeNodeReplicaReport {
     pub time: SystemTime,
     pub interval: Duration,
 }
+
+#[derive(Serialize)]
+pub struct ServiceStatesNotifier {
+    pub reminder_backoff_counter: u16,
+}
