@@ -6,7 +6,6 @@
 
 use time;
 
-use serde_derive::Serialize;
 use url_serde::SerdeUrl;
 
 use crate::prober::states::ServiceStates;
@@ -14,7 +13,7 @@ use crate::APP_CONF;
 
 const LOGO_EXTENSION_SPLIT_SPAN: usize = 4;
 
-lazy_static::lazy_static! {
+lazy_static! {
     pub static ref INDEX_CONFIG: IndexContextConfig = IndexContextConfig {
         runtime_version: env!("CARGO_PKG_VERSION").to_string(),
         page_title: APP_CONF.branding.page_title.to_owned(),
